@@ -45,10 +45,14 @@ class InvalidHeader(Exception):
         return 'Invalid request header. ' + json.dumps(self.errors)
 
 
-class TooMuchArguments(Exception):
+class TooManyArguments(Exception):
     """
     Got more arguments in request then expected
     """
 
     def __init__(self, msg):
         self.message = msg
+
+
+TooMuchArguments = TooManyArguments
+"""backward compatibility for version 3.0.0"""
